@@ -1,9 +1,7 @@
-from fief.models.account import Account
-from fief.models.account_user import AccountUser
 from fief.models.admin_api_key import AdminAPIKey
 from fief.models.admin_session_token import AdminSessionToken
 from fief.models.authorization_code import AuthorizationCode
-from fief.models.base import AccountBase, MainBase
+from fief.models.base import MainBase, WorkspaceBase
 from fief.models.client import Client
 from fief.models.generics import M_UUID, M
 from fief.models.grant import Grant
@@ -12,11 +10,13 @@ from fief.models.refresh_token import RefreshToken
 from fief.models.session_token import SessionToken
 from fief.models.tenant import Tenant
 from fief.models.user import User
+from fief.models.workspace import Workspace
+from fief.models.workspace_user import WorkspaceUser
 
 __all__ = [
-    "Account",
-    "AccountBase",
-    "AccountUser",
+    "Workspace",
+    "WorkspaceBase",
+    "WorkspaceUser",
     "AdminAPIKey",
     "AdminSessionToken",
     "AuthorizationCode",
