@@ -12,9 +12,7 @@ class AdminAPIKey(UUIDModel, CreatedUpdatedAt, MainBase):
     __tablename__ = "admin_api_key"
 
     name: str = Column(String(length=255), nullable=False)
-    token: str = Column(
-        String(length=255), default=secrets.token_urlsafe, unique=True, nullable=False
-    )
+    token: str = Column(String(length=255), unique=True, nullable=False)
     workspace_id: UUID4 = Column(GUID, ForeignKey(Workspace.id, ondelete="CASCADE"), nullable=False)  # type: ignore
 
     def __repr__(self) -> str:
